#!/usr/bin/env python
"""
A dedicated minificator for pdf.js
"""
import sys
import re

SAFE_SYMBOLS = ';:='

def strip_symbols(data, symbols):
    for sym in symbols:
        data = re.sub(''.join((' ', sym, ' ')), sym, data)
        data = re.sub(''.join((sym, ' ')), sym, data)
        data = re.sub(''.join((' ', sym)), sym, data)
    return data

def strip_comments(data):
    # Strip all comments
    data = re.sub(
    '(/\*([^*]|[\r\n]|(\*+([^*/]|[\r\n])))*\*+/)|(//.*)', '', data,
    )
    return data

def minify(data, level=1):
    # Level 1
    if level < 2:
        data = strip_comments(data)
        data = re.sub(' +', ' ', data)
        data = re.sub('\\t', '', data)
        #data = re.sub('\\n', '', data)
        data = strip_symbols(data, SAFE_SYMBOLS)
    return data

class Minificator(object):

    def __init__(self):
        self.data = None

    def read(self, file_path):
        """
        Read and store the text
        """
        path = file_path
        try:
            with open(path, 'r') as fd:
                self.data = fd.read()
        except IOError, e:
            print "Error: could not open file \'%s\': %s" % (path, e)

    @property
    def has_data(self):
        return True if self.data else False

    def write(self):
        print minify(self.data)


def usage():
    return """%s - a dedicated minificator for pdf.js

Usage:
    ./%s pdf.js > pdf.min.js
    """ % tuple(2*[sys.argv[0]])

def main():
    try:
        path = sys.argv[1]
    except IndexError:
        print usage()
        sys.exit(0)

    mini = Minificator()
    mini.read(path)
    if mini.has_data:
        mini.write()
    sys.exit(1)


if __name__ == '__main__':
    main()



#!/usr/bin/env python
"""
Lame tests, please ignore
"""

import re

fdi = open('pdf.js', 'r')
old_soup = fdi.read()
soup = old_soup[:]
print soup[:300]
fdi.close()

fdo = open('pdf.min.js', 'w')

# Strip comments
soup = re.sub(
    '(/\*([^*]|[\r\n]|(\*+([^*/]|[\r\n])))*\*+/)|(//.*)',
    '', soup)
# remove tabs
soup = re.sub('\\t', '', soup)
soup = re.sub(': ', ':', soup)
# remove multiple spaces
soup = re.sub(' +', ' ', soup)
# remove newlines
soup = re.sub('\\n', '', soup)

# Optimize
soup = re.sub(' \|\| ', '\|\|', soup)
soup = re.sub(' = ', '=', soup)
soup = re.sub(' : ', ':', soup)
soup = re.sub(' / ', '/', soup)
soup = re.sub(' + ', '+', soup)
soup = re.sub(' - ', '-', soup)
soup = re.sub('; ', ';', soup)
soup = re.sub(' \? ', '?', soup)
soup = re.sub(', ', ',', soup)
soup = re.sub(' {', '{', soup)
soup = re.sub('{ ', '{', soup)
soup = re.sub(' }', '}', soup)
soup = re.sub('} ', '}', soup)

fdo.write(soup)
print
print soup[:300]
fdo.close()



from  plone.app.testing import PloneSandboxLayer
from  plone.app.testing import applyProfile
from  plone.app.testing import PLONE_FIXTURE
from  plone.app.testing import IntegrationTesting

from plone.testing import z2

from zope.configuration import xmlconfig

class PdfJs(PloneSandboxLayer):

    defaultBases = (PLONE_FIXTURE,)

    def setUpZope(self, app, configurationContext):
        # Load ZCML
        import collective.pdfjs
        self.loadZCML(package=collective.pdfjs)
        z2.installProduct(app, 'collective.pdfjs')

    def setUpPloneSite(self, portal):
        applyProfile(portal, 'collective.pdfjs:default')

    def tearDownZope(self, app):
        z2.uninstallProduct(app, 'collective.pdfjs')


PDFJS_FIXTURE = PdfJs()
PDFJS_INTEGRATION_TESTING = IntegrationTesting(
    bases=(PDFJS_FIXTURE,),
    name="PdfJs:Integration",
)



import unittest2 as unittest

import transaction

from plone.app.testing import setRoles
from plone.app.testing import TEST_USER_ID
from plone.testing.z2 import Browser

from Products.CMFCore.utils import getToolByName

from collective.pdfjs.testing import PDFJS_INTEGRATION_TESTING

class TestSetup(unittest.TestCase):

    layer = PDFJS_INTEGRATION_TESTING

    def test__verify_installation(self):
        """Check if installed"""
        portal = self.layer['portal']
        qi = getToolByName(portal, 'portal_quickinstaller')
        self.assertTrue(
            qi.isProductInstalled('collective.pdfjs'))

    def test__verify_my_stylesheets(self):
        """Check for stylesheets"""
        portal = self.layer['portal']
        css = getToolByName(portal, 'portal_css')
        self.assertTrue(
            '++resource++collective.pdfjs.stylesheets/pdfjs.css'
            in css.getResourceIds())

    def test__verify_my_ecmascripts(self):
        """Check for scripts"""
        portal = self.layer['portal']
        jss = getToolByName(portal, 'portal_javascripts')
        scripts = [
        '++resource++collective.pdfjs.ecmascripts/pdf.js',
        '++resource++collective.pdfjs.ecmascripts/pdf.min.js'
        ]
        for s in scripts:
            self.assertTrue(s in jss.getResourceIds())

    def test__verify_my_view(self):
        """Check that the 'pdfjs_file_view is installed correctly,
        and viewable"""
        portal = self.layer['portal']
        setRoles(portal, TEST_USER_ID, ['Manager'])
        portal.invokeFactory('File', 'test_pdf', title=u"Tracemonkey PDF")
        transaction.commit()
        browser = Browser(portal)
        browser.open(portal['test_pdf'].absolute_url() + '/pdfjs_file_view')
        # A DOM element associated with this view is present
        self.assertTrue('#controls-wrapper' in browser.contents)


